# compare orthologous genes and GO terms between mouse and devil ENSEMBL databases

# get mouse ensembl biomart v103
ensembl <- useEnsembl(biomart = "ENSEMBL_MART_ENSEMBL", host = "https://feb2021.archive.ensembl.org")
datasets <- listDatasets(ensembl)
mm10 <- useDataset(dataset = "mmusculus_gene_ensembl", mart = ensembl)
shar <- useDataset(dataset = "sharrisii_gene_ensembl", mart = ensembl)

# get orthologous sequences for devil through biomart
attributes = c("ensembl_gene_id","sharrisii_homolog_ensembl_gene")
orth.devil = getBM(attributes,filters="with_sharrisii_homolog",values=TRUE, mart = mm10, bmHeader=FALSE)
dim(orth.mouse)
# 25734
length(unique(orth.devil$sharrisii_homolog_ensembl_gene))
# 17141

# Compare to total devil genes and GO terms in biomart
attributes = c("ensembl_gene_id", "go_id")
devil = getBM(attributes,filters ="with_go" , values=TRUE, mart = shar, bmHeader=FALSE)
length(unique(devil$ensembl_gene_id))
# 23792
length(unique(devil$go_id))
# 14154
devil = as.data.table(devil)
split.devil = devil %>% split(by="go_id") ## split by go_id
metrics.devil = lapply(split.devil, function(x) as.data.frame(x) %>% group_by(go_id) %>%
    summarise(count = n(), .groups = 'drop') %>% as.data.table()) # count how many genes per GO term
summary.devil = rbindlist(metrics.devil,)
write.table()

mouse = getBM(attributes, filters ="with_go", values=TRUE, mart = mm10, bmHeader=FALSE)
length(unique(mouse$ensembl_gene_id))
# 53700
length(unique(mouse$go_id))
# 3930
mouse = as.data.table(mouse)
split.mouse = mouse %>% split(by="go_id") ## split by go_id

metrics.mouse = lapply(split.mouse, function(x) as.data.frame(x) %>% group_by(go_id) %>%
    summarise(count = n(), .groups = 'drop') %>% as.data.table()) # count how many genes per GO term
summary.mouse = rbindlist(metrics.mouse,)
write.table()
list = list(summary.devil, summary.mouse) # combine devil and mouse into a list
merged <- list %>% purrr::reduce(full_join, by = "go_id")  # join all dataframes by go_id
names(merged) = c("go_id", "devil", "mouse")
merged.df <- replace(merged,is.na(merged),0)
range(merged.df$devil)
# 0 4395
range(merged.df$mouse)
# 0 3009

median(merged.df$devil)
median(merged.df$mouse)


summary.mouse$species = "mouse"
summary.devil$species = "devil"
df = rbind(summary.mouse, summary.devil)
pdf("genes_per_go_mouse_devil.pdf")
ggplot(df, aes(factor(species), y = count))+
    geom_violin(aes(fill=factor(species), color=factor(species)), position = "dodge") + 
    geom_boxplot(aes(color=factor(species)),
    width = .15, outlier.shape = NA,
    position = position_dodge(width=.1), 
    notch=TRUE) +
    theme(
        strip.background = element_blank(),
        strip.placement = "outside", axis.text.x = element_text(angle = 45, , hjust = 1, size = 25) 
        ) + theme_bw() + xlab("") + ylab("number of genes per GO term") + scale_fill_brewer(palette ="Spectral")
    