# This code compare the nearest genes calls before and after liftOver
# for alignable peaks between mouse and dunnart to assess the accuracy of the
# liftOver.
# After filtering only for genes with peaks that map to the same gene 
# before and after liftOver GO enrichment is performed.

## Load packages
library(data.table)
library(tidyverse)
library(ChIPseeker)
library(org.Mm.eg.db)
library(biomaRt)
library(GenomicFeatures)
library(TxDb.Mmusculus.UCSC.mm10.ensGene)
edb = TxDb.Mmusculus.UCSC.mm10.ensGene
library(GOSemSim)
mmGO = godata('org.Mm.eg.db', ont="BP") 
library(clusterProfiler)
library(enrichplot)
library(UpSetR)



mm10_txdb = makeTxDbFromBiomart(biomart = "ENSEMBL_MART_ENSEMBL", 
                                host = "feb2021.archive.ensembl.org",
                                dataset = "mmusculus_gene_ensembl",
                                port=80)

setwd("/data/projects/punim0586/lecook/chipseq-pipeline/cross_species/peakAnnotation/")
smiCra_txdb <- makeTxDbFromGFF("Scras_dunnart_assem1.0_pb-ont-illsr_flyeassem_red-rd-scfitr2_pil2xwgs2_60chr2.gff")
## geneID conversion tables
df2 <- read.table("biomart_ensembl.txt", header=TRUE, sep="\t")
df3 <- read.table("bioDBnet_refseq2ensembl_H3K27ac.txt", header=TRUE, sep="\t")


setwd("data/projects/punim0586/lecook/chipseq-pipeline/cross_species/peakAnnotation/overlaps")

compare_nearest_genes = function(bedList, i, j){
        reciprocal.to.dunnart = as.list(list.files(bedList, pattern= "annotation_smiCraTOmm10_mm10TOsmiCra.bed", full.names=T))
        reciprocal.to.dunnart.anno <- lapply(reciprocal.to.dunnart, annotatePeak, tssRegion = c(-3000, 3000), TxDb = smiCra_txdb,
                                                verbose=FALSE)
        names(reciprocal.to.dunnart.anno) = c("100bp", "200bp", "300bp", "400bp", "500bp", "50bp")
        reciprocal.to.dunnart.annoList = list(reciprocal.to.dunnart.anno[[1]]@anno, reciprocal.to.dunnart.anno[[2]]@anno,
                        reciprocal.to.dunnart.anno[[3]]@anno, reciprocal.to.dunnart.anno[[4]]@anno,
                        reciprocal.to.dunnart.anno[[5]]@anno, reciprocal.to.dunnart.anno[[6]]@anno)
        peakAnnoDF <- lapply(reciprocal.to.dunnart.annoList, function(x) as.data.table(x))
        
        # Convert refseq IDs and geneIDs to devil ensembl IDs
        peakAnnoDF = lapply(peakAnnoDF, function(x) x[,ensemblgeneID:=df2$Gene.stable.ID[match(unlist(x$geneId), df2$Gene.name)]])
        peakAnnoDF = lapply(peakAnnoDF, function(x) x[,ensemblgeneID:=replace(x$ensemblgeneID,is.na(x$ensemblgeneID),"-")])
        peakAnnoDF = lapply(peakAnnoDF, function(x) x[,transcriptIdAltered:=gsub("\\..*","", x$transcriptId)])
        peakAnnoDF = lapply(peakAnnoDF, function(x) x[,refseqID:=df3$Ensembl.Gene.ID[match(unlist(x$transcriptIdAltered), df3$RefSeq.mRNA.Accession)]])
        peakAnnoDF = lapply(peakAnnoDF, function(x) x[,refseqID:=replace(x$refseqID,is.na(x$refseqID),"-")])
        peakAnnoDF = lapply(peakAnnoDF, function(x) x[,combined:=ifelse(x$refseqID == "-", x$ensemblgeneID, x$refseqID)])
        
        peakAnnoDF = lapply(peakAnnoDF, function(x) x[,ensemblgeneID_2:=df2$Gene.stable.ID[match(unlist(x[[i]]), df2$Gene.name)]])
        peakAnnoDF = lapply(peakAnnoDF, function(x) x[,ensemblgeneID_2:=replace(x$ensemblgeneID_2,is.na(x$ensemblgeneID_2),"-")])
        peakAnnoDF = lapply(peakAnnoDF, function(x) x[,transcriptIdAltered_2:=gsub("\\..*","", x[[j]])])
        peakAnnoDF = lapply(peakAnnoDF, function(x) x[,refseqID_2:=df3$Ensembl.Gene.ID[match(unlist(x$transcriptIdAltered_2), df3$RefSeq.mRNA.Accession)]])
        peakAnnoDF = lapply(peakAnnoDF, function(x) x[,refseqID_2:=replace(x$refseqID_2,is.na(x$refseqID_2),"-")])
        peakAnnoDF = lapply(peakAnnoDF, function(x) x[,combined_2:=ifelse(x$refseqID_2 == "-", x$ensemblgeneID_2, x$refseqID_2)])
        length.ensembl = lapply(peakAnnoDF, function(x) length(which(x$ensemblgeneID %like% "ENS" == TRUE)))
        length.refseq = lapply(peakAnnoDF, function(x) length(x$transcriptId))

        peakAnnoDF = lapply(peakAnnoDF, function(x) x[,refseq_score:=ifelse(x$V26 == x$transcriptId & x$transcriptId %like% "XM_", "1", "0")])
        peakAnnoDF = lapply(peakAnnoDF, function(x) x[,ensembl_score:=ifelse(x$combined == x$combined_2 & x$combined_2 %like% "ENS", "1", "0")])

        gene.comparison.refseq.counts = lapply(gene.comparison.refseq, function(x) length(which(x ==1)))        
        gene.comparison.ensembl.counts = lapply(gene.comparison.ensembl, function(x) length(which(x ==1)))
        return(peakAnnoDF)
}

promoters = compare_nearest_genes("promoters", "V25", "V26")
enhancers = compare_nearest_genes("enhancers", "V29", "V30")

# filter to peaks that lift Over back to the same nearest gene
promoters.filtered = lapply(promoters, function(x) x[x$ensembl_score == 1])
enhancers.filtered = lapply(enhancers, function(x) x[x$ensembl_score == 1])

# Convert devil ensembl to mouse ensembl
promoters.filtered = lapply(promoters.filtered, function(x) x[,mouseensembl:=df2$Mouse.gene.stable.ID[match(unlist(x$combined), df2$Gene.stable.ID)]])
promoters.filtered = lapply(promoters.filtered, function(x) x %>% dplyr::select(seqnames, start, end, width, geneId, transcriptId, distanceToTSS, refseq_score, ensembl_score, mouseensembl))
promoters.filtered[[6]][promoters.filtered[[6]] == ""] <- NA
write.table(promoters.filtered[[6]], file = "promoters.filtered.liftOver.50bpsummits.annotations.bed", sep="\t", quote=F, row.names=F, col.names = F)
enhancers.filtered = lapply(enhancers.filtered, function(x) x[,mouseensembl:=df2$Mouse.gene.stable.ID[match(unlist(x$combined), df2$Gene.stable.ID)]])
enhancers.filtered = lapply(enhancers.filtered, function(x) x %>% dplyr::select(seqnames, start, end, width, geneId, transcriptId, distanceToTSS, refseq_score, ensembl_score, mouseensembl))
enhancers.filtered[[6]][enhancers.filtered[[6]] == ""] <- NA
write.table(enhancers.filtered[[6]], file = "enhancers.filtered.liftOver.50bpsummits.annotations.bed", sep="\t", quote=F, row.names=F, col.names = F)

## convert back to mouse coordinates then intersect active peaks at each stage
system("liftOver -bedPlus=4 promoters.filtered.liftOver.50bpsummits.annotations.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters.filtered.liftOver.50bpsummits.annotations_smiCraTOmm10.bed promoters.filtered.liftOver.50bpsummits.annotations_smiCraTOmm10_unmapped.bed")
system("liftOver -bedPlus=4 enhancers.filtered.liftOver.50bpsummits.annotations.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers.filtered.liftOver.50bpsummits.annotations_smiCraTOmm10.bed enhancers.filtered.liftOver.50bpsummits.annotations_smiCraTOmm10_unmapped.bed")

system("bedtools intersect -a promoters.filtered.liftOver.50bpsummits.annotations_smiCraTOmm10.bed -b promoters/E10.5.clustered.narrowPeak > E10.5.promoters.filtered.liftOver.50bpsummits.annotations_smiCraTOmm10_active.bed")
system("bedtools intersect -a enhancers.filtered.liftOver.50bpsummits.annotations_smiCraTOmm10.bed -b enhancers/E10.5_enhancer_peaks.narrowPeak > E10.5.enhancers.filtered.liftOver.50bpsummits.annotations_smiCraTOmm10_active.bed")
system("bedtools intersect -a promoters.filtered.liftOver.50bpsummits.annotations_smiCraTOmm10.bed -b promoters/E11.5.clustered.narrowPeak > E11.5.promoters.filtered.liftOver.50bpsummits.annotations_smiCraTOmm10_active.bed")
system("bedtools intersect -a enhancers.filtered.liftOver.50bpsummits.annotations_smiCraTOmm10.bed -b enhancers/E11.5_enhancer_peaks.narrowPeak > E11.5.enhancers.filtered.liftOver.50bpsummits.annotations_smiCraTOmm10_active.bed")
system("bedtools intersect -a promoters.filtered.liftOver.50bpsummits.annotations_smiCraTOmm10.bed -b promoters/E12.5.clustered.narrowPeak > E12.5.promoters.filtered.liftOver.50bpsummits.annotations_smiCraTOmm10_active.bed")
system("bedtools intersect -a enhancers.filtered.liftOver.50bpsummits.annotations_smiCraTOmm10.bed -b enhancers/E12.5_enhancer_peaks.narrowPeak > E12.5.enhancers.filtered.liftOver.50bpsummits.annotations_smiCraTOmm10_active.bed")
system("bedtools intersect -a promoters.filtered.liftOver.50bpsummits.annotations_smiCraTOmm10.bed -b promoters/E13.5.clustered.narrowPeak > E13.5.promoters.filtered.liftOver.50bpsummits.annotations_smiCraTOmm10_active.bed")
system("bedtools intersect -a enhancers.filtered.liftOver.50bpsummits.annotations_smiCraTOmm10.bed -b enhancers/E13.5_enhancer_peaks.narrowPeak > E13.5.enhancers.filtered.liftOver.50bpsummits.annotations_smiCraTOmm10_active.bed")
system("bedtools intersect -a promoters.filtered.liftOver.50bpsummits.annotations_smiCraTOmm10.bed -b promoters/E14.5.clustered.narrowPeak > E14.5.promoters.filtered.liftOver.50bpsummits.annotations_smiCraTOmm10_active.bed")
system("bedtools intersect -a enhancers.filtered.liftOver.50bpsummits.annotations_smiCraTOmm10.bed -b enhancers/E14.5_enhancer_peaks.narrowPeak > E14.5.enhancers.filtered.liftOver.50bpsummits.annotations_smiCraTOmm10_active.bed")
system("bedtools intersect -a promoters.filtered.liftOver.50bpsummits.annotations_smiCraTOmm10.bed -b promoters/E15.5.clustered.narrowPeak > E15.5.promoters.filtered.liftOver.50bpsummits.annotations_smiCraTOmm10_active.bed")
system("bedtools intersect -a enhancers.filtered.liftOver.50bpsummits.annotations_smiCraTOmm10.bed -b enhancers/E15.5_enhancer_peaks.narrowPeak > E15.5.enhancers.filtered.liftOver.50bpsummits.annotations_smiCraTOmm10_active.bed")


promoters = as.list(list.files(pattern= "promoters.filtered.liftOver.50bpsummits.annotations_smiCraTOmm10_active.bed", full.names=T))
promoters = lapply(promoters, function(x) fread(x, header=FALSE, sep="\t", quote = "", na.strings=c("", "NA"))) # read in all files
names(promoters) = c("E10.5", "E11.5", "E12.5", "E13.5", "E14.5", "E15.5")
promoters = Map(mutate, promoters, stage = names(promoters))

enhancers = as.list(list.files(pattern= "enhancers.filtered.liftOver.50bpsummits.annotations_smiCraTOmm10_active.bed", full.names=T))
enhancers = lapply(enhancers, function(x) fread(x, header=FALSE, sep="\t", quote = "", na.strings=c("", "NA"))) # read in all files
names(enhancers) = c("E10.5", "E11.5", "E12.5", "E13.5", "E14.5", "E15.5")
enhancers = Map(mutate, enhancers, stage = names(enhancers))


###################################################################################################
############################### GENE ONTOLOGY & PATHWAY ANALYSIS ##################################
###################################################################################################

# Background for calculating enrichment
# These are mouse ENSEMBL IDs for genes where there is an orthologous gene in the Tas devil 
bg=fread("../go_background_orthologousENSEMBL_biomart.txt", header=FALSE, sep="\t", quote = "", na.strings=c("", "NA"))
bg = unlist(bg, use.names=FALSE, recursive = TRUE)
bg = unique(bg)
genes = lapply(enhancers, function(i) as.data.frame(i)$V10)
names(genes) = c("E10.5", "E11.5", "E12.5", "E13.5", "E14.5", "E15.5")

go_cluster <- compareCluster(
        geneCluster = genes, 
        fun = enrichGO, 
        ont="BP",
        universe = bg,
        keyType="ENSEMBL", 
        OrgDb = org.Mm.eg.db)

## Dotplot
write.table(go_cluster@compareClusterResult, file = "promoter_conservedPeaks_compareCluster_enrichGO.txt", sep="\t", quote=F, row.names=F, col.names = F)
pdf("enhancer_conservedPeaks.pdf", width = 10, heigh = 5)
print(dotplot(go_cluster, showCategory = 5) + 
scale_color_viridis() +
theme(axis.text.x = element_text(angle = 45, hjust=1)))
dev.off()

genes = lapply(enhancers, function(i) as.data.frame(i)$V9)
names(genes) = c("E10.5", "E11.5", "E12.5", "E13.5", "E14.5", "E15.5")

go_cluster <- setReadable(
        compareCluster(
        geneCluster = genes, 
        fun = enrichGO, 
        ont="BP",
        universe = bg,
        keyType="ENSEMBL", 
        pvalueCutoff = 0.05, 
        OrgDb = org.Mm.eg.db),
      OrgDb = org.Mm.eg.db, 
      keyType="ENSEMBL")

write.table(go_cluster@compareClusterResult, file = "enhancer_conservedPeaks_compareCluster_enrichGO.txt", sep="\t", quote=F, row.names=F, col.names = F)

## Dotplot
pdf("enhancer_conservedPeaks.pdf"), width = 20, height = 15)
print(dotplot(go_cluster, showCategory = 10) + 
scale_color_viridis() +
theme(axis.text.x = element_text(angle = 45, hjust=1)))
dev.off()

# union of conserved-peaks across the different embryonic stages
union_promoter_conserved_peaks <- unique(c(promoters$E10.5$V10, promoters$E11.5$V10, promoters$E12.5$V10,
promoters$E13.5$V10, promoters$E14.5$V10, promoters$E15.5$V10)) 
length(union_promoter_conserved_peaks)
# 984

union_enhancer_conserved_peaks <- unique(c(enhancers$E10.5$V10, enhancers$E11.5$V10, enhancers$E12.5$V10,
enhancers$E13.5$V10, enhancers$E14.5$V10, enhancers$E15.5$V10)) 
length(union_enhancer_conserved_peaks)
# 74

## Make dataframe for assessing gene intersections
upsetPlot = function(x, plot){
        subset = lapply(x, function(x) x %>% dplyr::select(V10) %>% as.data.table() %>% unique())
        subset = Map(mutate, subset, stage = names(subset)) 
        merged <- subset %>% purrr::reduce(full_join, by = "V10")  # join all dataframes by ensembl geneID
        merged[is.na(merged)] <- 0
        merged = as.data.frame(merged)
        geneId = merged$V10
        colnames(merged) = c("genes", "E10.5", "E11.5", "E12.5", "E13.5", "E14.5", "E15.5")
        upset.df = data.frame(lapply(merged[,2:7], function(x) as.numeric(x!="0")))
        rownames(upset.df) = geneId

        ## Upset plot
        pdf(plot)
        print(upset(upset.df, 
        nsets=6, order.by="freq", text.scale = 2,
        sets = c("E10.5","E11.5","E12.5", "E13.5","E14.5", "E15.5"),
        keep.order = T, mainbar.y.label = "number of genes",
        number.angles = 45))
        dev.off()
}

# plot gene interactions
upsetPlot(promoters, "promoter_conserved_upsetPlot.pdf")
upsetPlot(enhancers, "enhancer_conserved_upsetPlot.pdf")

