# This code takes dunnart and mouse peak annotations
# And extracts the genomic annotation feature
# and plots it (eg. Promoter, Coding, Intergenic)

# Load in libraries
library(data.table) 
library(tidyverse)
library(ggridges)
library(ggpubr)
library(reshape2)
library(RColorBrewer)
library(ggplot2)
library(VennDiagram)
library(viridis)
library(hrbrthemes)
library(gghalves)
library(ComplexHeatmap)
library(plyr)

setwd("/data/projects/punim0586/lecook/chipseq-pipeline/cross_species/peakAnnotation")
genomicRegions <- function(fileList, annotation, colors){
    files =list.files(fileList, pattern= ".txt", full.names=T) # create list of files in directory
    files = as.list(files)
    data = lapply(files, function(x) fread(x, header=TRUE, sep="\t", quote = "", na.strings=c("", "NA"))) # read in all files
    names(data) = c("P0","E10.5","E11.5","E12.5", "E13.5","E14.5", "E15.5")
    subset = lapply(data, function(x) x %>% dplyr::select(annotation) %>% as.data.table())
    df1 = Map(mutate, subset, stage = names(subset))
    df1 = rbindlist(df1,) ## bind rows back together
    df1 = map_df(df1, ~ gsub(" .*", "", .x))# remove everything after the first space
    df1 = df1[complete.cases(df1), ]
    tbl = with(df1, table(annotation, stage)) %>% as.data.frame()
    
    # Plot proportion of peaks in each genomic region
    pdf(annotation, width=10, height=6)
    ggplot(tbl, aes(factor(stage), Freq, fill=annotation)) + 
    geom_bar(position=position_stack(reverse = FALSE), stat="identity") +
    #geom_text(data=subset(data,Freq != 0),aes(label=Freq, y=pos), size=3)+
    scale_fill_manual(values = colors)  + 
    theme_minimal() + ylab("Number of peaks") +
    xlab("")
    dev.off()
}

genomicRegions(fileList = "consensus/promoters/clustered", annotation = "genomicRegions_promoters.pdf", colors =c('#4d004b','#810f7c','#88419d','#8c6bb1','#8c96c6','#9ebcda','#bfd3e6'))
genomicRegions(fileList = "consensus/enhancers/annotation", annotation = "genomicRegions_enhancers.pdf", colors =c('#fff7ec','#fee8c8','#fdd49e','#fdbb84','#fc8d59','#ef6548','#d7301f','#b30000','#7f0000'))


colors =c('#084081','#0868ac','#2b8cbe','#4eb3d3','#7bccc4','#a8ddb5','#ccebc5')