# GC content and CpG % plots 

# Purpose
library(data.table) 
library(tidyverse)
library(ggridges)
library(ggpubr)
library(reshape2)
library(RColorBrewer)
library(ggplot2)
library(VennDiagram)
library(viridis)
library(hrbrthemes)
library(gghalves)
library(dplyr)

setwd("/data/projects/punim0586/lecook/chipseq-pipeline/dunnart/results/macs2/")
promoter <- fread("annotations/dunnart_promoters_homerAnnot.txt")
enhancer <- fread("annotations/dunnart_enhancers_homerAnnot.txt")
peaks = list(promoter, enhancer)
peaks = Map(mutate,peaks,cre=c("promoters", "enhancers"))
peaks = lapply(peaks, function(x) x %>% dplyr::select("Chr", "Start", "End", "Peak Score", "Distance to TSS", "CpG%", "GC%", "cre") %>% as.data.table())
peaks = rbindlist(peaks)
colnames(peaks)[5:7] <- c("distanceToTSS","CpG", "GC")
peaks[is.na(peaks)] <- 0
peaks = peaks[,log10_abs_dist:=log10(abs(distanceToTSS)+1)][,log10_abs_dist:=ifelse(distanceToTSS<0,-log10_abs_dist,log10_abs_dist)]
promoter = subset(peaks, cre == "promoters")
enhancer = subset(peaks, cre == "enhancers")
promoter_k = copy(promoter)

## kmeans clustering
promoter.kmeans = kmeans(promoter_k[,9], 3, iter.max = 1000, nstart=25)
promoter.kmeans_table = data.frame(promoter.kmeans$size, promoter.kmeans$centers)
promoter.kmeans_df = data.frame(Cluster = promoter.kmeans$cluster, promoter_k[,9])
promoter_k$meanK <- promoter.kmeans_df$Cluster
enhancer$meanK <- "enhancer"
promoter$meanK <- "promoter"

p <- ggplot(promoter.kmeans_df, aes(x=log10_abs_dist, fill=as.factor(Cluster), color=as.factor(Cluster))) + 
            geom_histogram(binwidth=0.1, position = 'identity')  +
            theme_bw()+ font
  pdf("homer.Annot.kmeans.pdf", width = 10, height = 7)
  print(p + scale_color_manual(values = c('#4D004B','#8C6BB1','#9EBCDA')) + scale_fill_manual(values = c('#4D004B','#8C6BB1','#9EBCDA')))
  dev.off()

data = rbind(enhancer, promoter, promoter_k)

p <- ggplot(data, aes(factor(meanK), y = GC)) + 
  geom_violin(aes(fill=factor(meanK), color=factor(meanK)),
   position = "dodge"
   )+
  geom_boxplot(aes(color=factor(meanK)),
    outlier.shape = NA,
    width = .15, 
    notch = TRUE,
    fill=c("#D3BFD2","#D4C7E2","#E7EEF6", "#FCF8EC","#E4F3F1"),
    position = position_dodge(width=.1)
  ) + theme_bw() + xlab("") + ylab("GC content") 
  pdf("dunnart_GC.pdf", width=9, height = 8)
  print(p +  scale_color_manual(values = c('#4D004B','#8C6BB1','#9EBCDA', '#E9C46A','#2A9D8F')) +
  scale_fill_manual(values = c("#7A4078","#A990C4","#B6CDE3" ,"#F1DAA2","#7AC2B9")) + font) 
  dev.off()

  p <- ggplot(data, aes(factor(meanK), y = CpG)) + 
  geom_violin(aes(fill=factor(meanK), color=factor(meanK)),
   position = "dodge"
   )+
  geom_boxplot(aes(color=factor(meanK)),
    outlier.shape = NA,
    width = .15, 
    notch = TRUE,
    fill=c("#D3BFD2","#D4C7E2","#E7EEF6", "#FCF8EC","#E4F3F1"),
    position = position_dodge(width=.1)
  ) + theme_bw() + xlab("") + ylab("CpG") 
  pdf("dunnart_CpG.pdf", width=9, height = 8)
  print(p +  scale_color_manual(values = c('#4D004B','#8C6BB1','#9EBCDA', '#E9C46A','#2A9D8F')) +
  scale_fill_manual(values = c("#7A4078","#A990C4","#B6CDE3" ,"#F1DAA2","#7AC2B9")) + font) 
  dev.off()