## Number of peaks per gene and distance to the nearest gene

library(dplyr)
library(tidyverse)
library(data.table)
library(rtracklayer)
library(ggpubr)
library(grid)


setwd("/data/projects/punim0586/lecook/chipseq-pipeline/dunnart/results/macs2/annotations/")
setwd("/data/projects/punim0586/lecook/chipseq-pipeline/dunnart/results/macs2/")

getGeneCoord <- function(fileList, promoter, enhancer){
  files = as.list(fileList)
  data = lapply(files, function(x) fread(x, header=TRUE, sep="\t", quote = "", na.strings=c("", "NA"))) # read in all files
  subset = lapply(data, function(x) x %>% dplyr::select(seqnames, geneId, geneStart, geneEnd, geneStrand) %>% as.data.table())
  reorder = lapply(subset, function(x) setcolorder(x, c("seqnames", "geneStart", "geneEnd", "geneId", "geneStrand")) %>% as.data.table())
  reorder = lapply(reorder, function(x) x[,geneStrand := as.character(geneStrand)][geneStrand == "1", geneStrand := "+"])
  reorder = lapply(reorder, function(x) x[,geneStrand := as.character(geneStrand)][geneStrand == "2", geneStrand := "-"])
  write.table(reorder[[1]], enhancer, sep="\t", quote=F, row.names=F, col.names=F)
  write.table(reorder[[2]], promoter, sep="\t", quote=F, row.names=F, col.names=F)
}
getGeneCoord(fileList = c("dunnart_enhancer_annotation.txt", "dunnart_promoter_annotation.txt"), enhancer ="enhancer_reordered_geneCoords.bed", promoter="promoter_reordered_geneCoords.bed")

#system("bedtools sort -i enhancer_reordered_geneCoords.bed | bedtools merge -i stdin -s -c 5,5,6 -o count,distinct,distinct > enhancer_reordered_geneCoordsMerged.bed", intern = TRUE) ## sort by coordinates
#system("bedtools sort -i promoter_reordered_geneCoords.bed | bedtools merge -i stdin -s -c 5,5,6 -o count,distinct,distinct > promoter_reordered_geneCoordsMerged.bed", intern = TRUE) ## bedtools merge where transcripts are the same coordinates or within each other

genesPerScaffold <- function(file, distances){
  data = fread(file, header=FALSE, sep="\t", quote = "", na.strings=c("", "NA")) # read in all files
  colnames(data) <- c("seqnames", "start", "end","gene", "strand")
  data$type <- "peak"
  peak.counts <- data %>% as.data.frame() %>% group_by(gene) %>%
    summarise(count = n()) %>% as.data.table()

  gffRangedData<-import.gff("../Scras_dunnart_assem1.0_pb-ont-illsr_flyeassem_red-rd-scfitr2_pil2xwgs2_60chr2.gff")
  allGenes<-as(gffRangedData, "GRanges")
  allGenesDT <- as.data.table(allGenes)
  allGenesDT = allGenesDT %>% dplyr::select(seqnames, start, end, strand, type, gene) %>% as.data.table() %>% setcolorder(c("seqnames", "start", "end","gene", "strand", "type"))
  allGenesDT.filtered = dplyr::filter(allGenesDT, type == "gene")
  allGenesDT.filtered = setcolorder(allGenesDT.filtered, c("seqnames", "start", "end","gene", "strand", "type"))
  bind = rbind(data, allGenesDT.filtered)
  split = bind %>% split(by="seqnames") ## split by scaffold
 # df = lapply(split, function(x) rbindlist(x)) ## bind rows back together
  split = lapply(split, function(x) subset(x, nrow(x) > 1)) ## remove dataframes that only have 1 row per gene
  split = split[sapply(split, function(x) dim(x)[1]) > 0] ## remove empty dataframes

  ## Count number of genes per scaffold and number of peaks
  scaffold.vs.peakCount = copy(split)
  metrics = lapply(scaffold.vs.peakCount, function(x) as.data.frame(x) %>% group_by(type) %>%
    summarise(count = n(), .groups = 'drop') %>% as.data.table())
  split2 = lapply(metrics, function(x) subset(x, nrow(x) > 1)) ## remove dataframes that only have 1 row per gene
  filter = split2[sapply(split2, function(x) dim(x)[1]) > 0] ## remove empty dataframes
  df1 = Map(mutate, filter, scaffold = names(filter))
  df1 = lapply(df1, function(x) x = dcast(x, scaffold ~ type, value.var = "count"))
  df1 = rbindlist(df1,) ## bind rows back together
  return(df1)

  ## Now compare the distances between the nearest gene and number of peaks
  split = lapply(split, function(x) unique(x, by = "gene"))
  split = lapply(split, function(x) x=setorderv(x,c('start', 'end'),1)) ## order peaks on start stop coordinates
  split = lapply(split, function(x) x=x[,distanceBetweenPeaks:=lead(start)-start]) ## find distance between peaks with the same nearest gene
  split = lapply(split, function(x) x=x[,distanceBetweenPeaksRev:=abs(lag(start)-start)]) ## find distance between peaks with the same nearest gene
  split = lapply(split, function(x) x=x[,closestGene:=ifelse(distanceBetweenPeaks<distanceBetweenPeaksRev, distanceBetweenPeaks, distanceBetweenPeaksRev)])
  split = lapply(split, function(x) x=x[,closestGene:=ifelse(is.na(closestGene), distanceBetweenPeaks, closestGene)])
  split = lapply(split, function(x) x=x[,closestGene:=ifelse(is.na(closestGene), distanceBetweenPeaksRev, closestGene)])
  distances = rbindlist(split,)
  distances = distances %>% dplyr::select(gene, closestGene) %>% as.data.table() 
  list = list(peak.counts, distances)
  merged <- list %>% purrr::reduce(full_join, by = "gene")  # join all dataframes by ensembl geneID
  merged = merged[complete.cases(merged), ]
  enhancer.dist = merged
}

promoter = genesPerScaffold(file = "promoter_reordered_geneCoords.bed", distances = data.table())
enhancer = genesPerScaffold(file = "enhancer_reordered_geneCoords.bed", distances = data.table())
promoter$cre = "promoter"
promoter.dist$cre = "promoter"
promoter.dist = copy(distances)

enhancer$cre = "enhancer"
enhancer.dist$cre = "enhancer"
enhancer.dist = copy(distances)
data = rbind(promoter, enhancer)
data=rbind(promoter.dist, enhancer.dist)
data = data[,log10.dist:=log10(closestGene+1)]

ggplot(data, aes(x=count, y=log10.dist)) + geom_point()

pdf("test.pdf")
p <- ggscatter(
  data, x = "closestGene", y = "count",
  color = "cre", palette = "jco", add="reg.line",
  conf.int = TRUE, # Add confidence interval
  cor.coef = TRUE, # Add correlation coefficient. see ?stat_cor
  cor.coeff.args = list(method = "pearson", label.x = 3, label.sep = "\n"), xlab = "Distance to the closest gene",
  ylab = "Number of peaks per gene"
  ) +
  facet_wrap(~cre)
p + theme(panel.spacing = unit(2, "lines"), plot.margin = margin(2, 2, 2, 2, "cm"))
dev.off()