# Load in libraries
library(data.table) 
library(tidyverse)
library(ggridges)
library(ggpubr)
library(reshape2)
library(RColorBrewer)
library(ggplot2)
library(VennDiagram)
library(viridis)
library(hrbrthemes)
library(gghalves)
library(ComplexHeatmap)
library(plyr)

setwd("/data/gpfs/projects/punim0586/lecook/chipseq-pipeline/dunnart/results/macs2")

genomicRegions <- function(fileList, annotation, cpg, colors){
    files =list.files(fileList, pattern= "_homerAnnot.txt", full.names=T) # create list of files in directory
    files = as.list(files)
    data = lapply(files, function(x) fread(x, header=TRUE, sep="\t", quote = "", na.strings=c("", "NA"))) # read in all files
    data = lapply(data, function(x) x=setnames(x, old="CpG%", new="CpG", skip_absent=TRUE) %>% as.data.table())
    data = lapply(data, function(x) x=setnames(x, old="GC%", new="GC", skip_absent=TRUE) %>% as.data.table())
    names(data) = c("cluster1","cluster2","cluster3", "enhancers", "promoters")
    subset = lapply(data, function(x) x %>% dplyr::select(Annotation, CpG, GC) %>% as.data.table())
    df1 = Map(mutate, subset, stage = names(subset))
    df2 = rbind(df1$cluster1, df1$cluster2, df1$cluster3, df1$promoters, df1$enhancers)
    #df1 = rbindlist(df1,) ## bind rows back together
    df2 = map_df(df2, ~ gsub(" ().*", "", .x))# remove everything after the first space
    promoters_only = df2[complete.cases(df2), ]
    tbl = with(df2, table(Annotation, stage)) %>% as.data.frame()
    
    # Plot proportion of peaks in each genomic region
    pdf(annotation)
    ggplot(tbl, aes(factor(Annotation), Freq, fill=factor(stage))) + 
    geom_bar(position=position_stack(reverse = TRUE), stat="identity") +
    #geom_text(data=subset(data,Freq != 0),aes(label=Freq, y=pos), size=3)+
    scale_fill_manual(values = colors)  + 
    theme_minimal() + ylab("Number of peaks") +
    xlab("")
    dev.off()

    # Plot CpG % for each stage
    df3 = df2 %>% as.data.table()

    p = ggplot(df3, aes(x=stage, y = as.numeric(CpG))) + 
  #geom_violin(aes(fill=factor(cre), color=factor(cre)),
  #  position = "dodge"
  #  )+
    geom_boxplot(aes(color=stage),
    #outlier.shape = NA,
    width = .2, 
    notch = TRUE,
    fill=colors,
    position = position_dodge(width=.1),
    alpha = 0.5
    ) + theme_bw() + xlab("") + ylab("CpG %") 
    pdf(cpg, width=9, height = 8)
    print(p)
    dev.off()
}

genomicRegions(fileList = "annotations/", annotation = "plots/genomicRegions_promoters2.pdf", cpg = "plots/CpG_promoters.pdf", colors =c('#4d004b','#810f7c','#88419d','#8c6bb1','#8c96c6','#9ebcda','#bfd3e6'))
genomicRegions(fileList = "consensus/enhancers", annotation = "consensus/genomicRegions_enhancers.pdf", cpg = "consensus/CpG_enhancers.pdf", colors =c('#084081','#0868ac','#2b8cbe','#4eb3d3','#7bccc4','#a8ddb5','#ccebc5'))


