## script used to analyse homer tfbs known motifs results and get enrichment
library(dplyr)
library(data.table)
library(magrittr)
library(ComplexHeatmap)
library(circlize)
library(ggthemes)
library(ggplot2)
library(ggpubr)
library(viridis)
library(viridisLite)
library(RColorBrewer)
library(purrr)
library(rtracklayer)
options(width=150)

setwd('/data/projects/punim0586/lecook/chipseq-pipeline/dunnart/results/macs2/')
homer_dir = './motifEnrichment/'
plot_dir = './motifEnrichment/'

##-------------
## read motifs
##-------------
read_known_motifs = function(dir){
  known_motifs = fread(paste(homer_dir,dir,'knownResults.txt',sep=''),sep='\t',header=T)
  known_motifs = known_motifs[,motif_name:=gsub("\\/.*","",`Motif Name`)]
  families =stringr::str_extract(string = known_motifs$motif_name,pattern = "(?<=\\().*(?=\\))")
  known_motifs= known_motifs[
    ,motif_family:=families
    ][
      ,motif_name:=gsub("\\(.*","",motif_name)
      ][
        ,prop_motif_in_target:=as.numeric(gsub("\\%.*","",`% of Target Sequences with Motif`))
        ][
          ,c('Motif Name','Consensus','% of Target Sequences with Motif'):=NULL
          ]
  return(known_motifs)
}

dunnart_enhancerKnown = read_known_motifs('enhancers/')
dunnart_promoterKnown = read_known_motifs('cluster1_promoters/')
known_motif = list(dunnart_enhancerKnown, dunnart_promoterKnown)
known_motif = Map(mutate,known_motif,cre=c("enhancers", "promoters"))
number_initial_motifs = copy(known_motif)%>%lapply(function(x)as.data.table(x)[,'motif_name']%>%unique()%>%nrow())

##----------------
## filter motifs
##----------------
## FDR adjust pvalues
## remove motifs with fdr adj.pval > 0.01 
## remove motifs present in less than 5% of target sequences
filter_motifs= function(motif){
  filtered=copy(motif)
  # %>%as.data.table()
  # filtered$log_p_value[(filtered$log_p_value == Inf)] = max(filtered$log_p_value[is.finite(filtered$log_p_value)]+200)## this to counteact Inf
  filtered=filtered[
    ,log_pval:=ifelse(`Log P-value`< -729,-745,`Log P-value`) ## done this to control R from converting <<< 0 values to 0
    ][
      ,log10_fdr_adjP:=-log10(p.adjust(exp(log_pval),'fdr'))
      ][
        log10_fdr_adjP > 1.9
        ][
          prop_motif_in_target>0
          ][
            !motif_name %like% 'Unknown'
            ]
  # filtered=filtered[
  #   p.adj< 0.01
  #   ][
  #     ,tgt_pct:=round(tgt_pct,2)
  #     ][
  #       tgt_pct>0.05
  #       ][
  #         !motif_name %like% 'Unknown'
  #         ][
  #           ,motif_name:=ifelse(motif_name %like% 'BORIS','CTCFL',motif_name)
  #           ]
  # filtered=tibble(filtered)
  # names(filtered$motif_pwm)=filtered$motif_name
  return(filtered)
}


filtered_known_motif = lapply(known_motif,function(x)filter_motifs(x))
number_filtered_motifs = copy(filtered_known_motif)%>%lapply(function(x)as.data.table(x)[,'motif_name']%>%unique()%>%nrow())
##--------------
## plot results
##--------------
## important: GFY is a general factor Y, which refers to a motif for which HOMER doesnt know which if the factor that binds it (see http://homer.ucsd.edu/homer/motif/motifDatabase.html)
## however, these motifs are real and some TFs have been described binding them (see http://genesdev.cshlp.org/content/24/14/1479.long)
## what I'll do is to report the family for this as 'unknown' and in the text I will mention this and cite the above paper.
motifs_table = copy(filtered_known_motif)%>%lapply(function(x)x=x[,c('motif_name','motif_family','cre','log10_fdr_adjP')])%>%rbindlist()
motifs_table = motifs_table[,motif_family:=ifelse(motif_family=='?','Unknown',motif_family)][,motif_name_family:=paste(motif_name,motif_family,sep=':')][,c('motif_name','motif_family'):=NULL]
## create matrix for heatmap
matrix = copy(motifs_table)
matrixE = matrix[!cre=="promoters"]
matrixP = matrix[!cre=="enhancers"]
matrixE = unique(matrixE, by = "motif_name_family") %>% as.data.table()
matrixE = matrixE[log10_fdr_adjP>10,] %>% as.data.frame()
matrixP = unique(matrixP, by = "motif_name_family") %>% as.data.frame()
matrix = rbind(matrixE, matrixP) %>% as.data.table()
matrix = dcast(matrix, motif_name_family~cre,value.var='log10_fdr_adjP') %>% as.data.table()

matrix[is.na(matrix)]=0
matrix_rownames = matrix$motif_name_family
matrix = matrix[,motif_name_family:=NULL] %>% as.matrix()
rownames(matrix) = matrix_rownames
filtered_matrix = copy(matrix)
filtered_matrix=filtered_matrix[rowSums(filtered_matrix)>10, ]

filtered_matrix = filtered_matrix[!rownames(filtered_matrix) %like% 'SeqBias', ]
rownames(filtered_matrix)[19] <- "E-box:bHLH"

## get random colors for motif families 
#n_tf_families = length(unique(gsub(".*:","",rownames(filtered_matrix))))
#qual_col_palette = brewer.pal.info[brewer.pal.info$category == 'seq',]
#qual_col_palette = subset(qual_col_palette, rownames(qual_col_palette) %in% c("PuRd", "YlOrRd", "Greens"))

#qual_col_palette = subset(qual_col_palette, rownames(qual_col_palette) %in% c("Accent", "Set2", "Set3"))
#col_vector = unlist(mapply(brewer.pal, qual_col_palette$maxcolors, rownames(qual_col_palette)))
#tf_family_colors = sample(col_vector,n_tf_families)
tf_family_colors = c("#EF476F", "#FFD166","#2a9d8f", "#ffafcc", "#F4A261", "#E76F51", "#8EcAe6", "#219EBC", "#55a630", "#9d4edd", "#b56576",
"#0081a7", "#00AFB9", "#F07167", "#264653", "#06D6A0", "#a01a58", "#177E89", "#fec3a6", "#DB3A34", "#a5668b")

tf_family_colors = c("#E1455E",
 "#FBB055", "#FBD49D", "#F8A485","#B855A2","#85C5E0", "#95CA8A", 
 "#2E474E", "#58A699", "#E293BF",
"#EFD318", "#522B89", "#CA2161", "#CADF55", 
"#0F539E","#008552", "#BA00FF", "#56ADC4", 
"#E2E2E2","#EC468B", "#EF476F", "#a01a58", "#8EcAe6", "#ffafcc", "#F07167")

names(tf_family_colors) = unique(gsub(".*:","",rownames(filtered_matrix)))
tf_family_colors=tf_family_colors[-24:-25]

## plot heatmamp
homer_heatmap = function(x){
  Heatmap(
      x, 
      border = T, 
      col= c("#edf8b1", "#c7e9b4", "#7fcdbb", "#41b6c4", "#1d91c0", "#225ea8", "#253494", "#081d58"),
      row_dend_reorder = T,
      # row_order=order(as.character(gsub("^.*\\.", "", rownames(enrichmatrix)))),
      show_heatmap_legend = T,
      heatmap_legend_param = list(title = '-log10 fdr adj P'),
      show_row_names = T,
      row_labels = gsub("\\:.*", "", rownames(x)),
      row_title =" ",
      show_column_names = T,
      column_names_gp = gpar(fontsize = 10),
      column_names_rot = 70,
      column_title =' ',
      right_annotation = HeatmapAnnotation(
                  which='row',
                  width = unit(1.5,'cm'),
                  cluster = anno_simple(
                      gsub(".*:","",rownames(x)),
                      col= tf_family_colors
                      ),
                      show_annotation_name = F)
                      )
}
pdf(paste(plot_dir,'homer_known_heatmap.pdf',sep=''),width= 10,height = 20)
homer_heatmap(filtered_matrix)
dev.off()


##----------------------------
## create motif logo object
##----------------------------
## for this read again HOMER results but using marge 
## this allows to retrieve the PWMs for plotting
library(marge)
library(motifStack)
#chimp_known_pwms = read_known_results(paste(homer_dir,'chimp_specific_pantro5/',sep=''))
#common_known_pwms = read_known_results(paste(homer_dir,'common_regions_hg38/',sep=''))
#human_known_pwms = read_known_results(paste(homer_dir,'human_specific_hg38/',sep=''))
enhancer_known_pwms = read_known_results(paste(homer_dir,'enhancers/',sep=''))
promoter_known_pwms = read_known_results(paste(homer_dir,'cluster1_promoters/',sep=''))
enhancer_known_pwms = na.omit(enhancer_known_pwms)
promoter_known_pwms = na.omit(promoter_known_pwms)
my_motifs = list(enhancer_known_pwms, promoter_known_pwms)%>%lapply(function(y)y=dplyr::select(y,c('motif_name','motif_pwm'))%>%as.data.table())
my_motifs = lapply(my_motifs,function(x)x=x[motif_name %in% gsub('\\:.*','',rownames(filtered_matrix))])%>%rbindlist()%>%tibble()%>%unique()
names(my_motifs$motif_pwm)=my_motifs$motif_name
motif_names=as.list(my_motifs$motif_name)
motifs_pwm=copy(my_motifs$motif_pwm)
get_motif_logo=function(pwm,names){
  motifs=copy(pwm)%>%as.matrix()%>%t()
  colnames(motifs)=paste('V',1:dim(motifs)[2],sep='')
  motif_object= new("pcm", mat=motifs, name=names)
  return(motif_object)
}
my_motif_object= purrr::map2(motifs_pwm[599],motif_names[599],function(x,y)get_motif_logo(x,y))
pdf(paste(plot_dir,'logo_homer_top_known_gfy.pdf',sep=''),width= 15,height = 5)
lapply(my_motif_object,function(x)plot(x))
dev.off()

## now make a barplot with proportion motif families

enhancer = data.frame(motif_name_family = row.names(filtered_matrix), filtered_matrix[,1])
names(enhancer) <- c("motif_name_family", "logpvalue")
enhancer = enhancer[enhancer$logpvalue>0,]
enhancer[118] <- "RBPJ:bHLH"

promoter = data.frame(motif_name_family = row.names(filtered_matrix), filtered_matrix[,2])
names(promoter) <- c("motif_name_family", "logpvalue")
promoter = promoter[promoter$logpvalue>0,]

motif_families=data.table(motif_name_family=rownames(filtered_matrix))
promoter = data.table(motif_name_family=promoter$motif_name_family)
enhancer = data.table(motif_name_family=enhancer$motif_name_family)

motif_families = motif_families[
  ,c("motif_name", "motif_family") := tstrsplit(motif_name_family, ":", fixed=TRUE)
  ][
    ,'motif_name_family':=NULL
    ][
      ,numb_motifs_by_family:=.N,by=.(motif_family)
      ][
        ,numb_motifs:=.N
        ][
          ,prop_family:=numb_motifs_by_family/numb_motifs
          ][
            ,mock_col:='tf_family'
          ]

motif_families = enhancer[
  ,c("motif_name", "motif_family") := tstrsplit(motif_name_family, ":", fixed=TRUE)
  ][
    ,'motif_name_family':=NULL
    ][
      ,numb_motifs_by_family:=.N,by=.(motif_family)
      ][
        ,numb_motifs:=.N
        ][
          ,prop_family:=numb_motifs_by_family/numb_motifs
          ][
            ,mock_col:='tf_family'
          ]%>% setorderv("prop_family",1)

prop_motif_families = copy(motif_families)[,c('prop_family','motif_family','mock_col')]%>%unique()

prop_motif_families <- prop_motif_families[order(prop_motif_families$prop_family, decreasing = TRUE),] # (1)
prop_motif_families$prop_familyFactor <-factor(prop_motif_families$prop_family, levels= unique(prop_motif_families$prop_family) ) # (2)

pdf(paste(plot_dir,'prop_families_homer_top_known_motifs_promoters.pdf',sep=''),width= 5,height = 10)
ggplot(prop_motif_families,aes(x=mock_col,y=prop_family,fill=motif_family, group=prop_familyFactor))+
geom_bar(stat="identity")+
scale_fill_manual(values = tf_family_colors)+ theme_bw()
dev.off()